/*
 * $Id: migpost.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Finish migrating a ManageSoft 8.5 database into ManageSoft 8.6 format.
 *
 * Use migprep.sql first, then schema.sql, then this, and finally
 * install Managesoft 8.6 which will create the stored procedures.
 *
 * Called after building the new tables, this script:
 * - migrates data from old tables
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

/*
 * Check that we are upgrading from a 8.5 database...
 */
DECLARE @schema_version char(10)
SET @schema_version = (SELECT Value FROM DatabaseConfiguration
		WHERE Property = 'SchemaVersion')

IF (@schema_version = '8.5')
BEGIN
	PRINT 'Completing migration to ManageSoft 8.6 database schema...'
END
ELSE IF (@schema_version = '8.6')
BEGIN
	RAISERROR ('Your ManageSoft database has already been migrated to the 8.6 schema.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
ELSE
BEGIN
	RAISERROR ('This script can only migrate from the ManageSoft database schema version 8.5.', 16, 1)
	RAISERROR ('Please migrate your database schema to version 8.5 before executing this script again.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
GO


--===========================================================================
--		Update the DatabaseConfiguration table
--
--		NOTE: do this last
--===========================================================================
IF EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'MigrationStep' AND VALUE = 1000)
BEGIN
	PRINT 'Recording successful migration'
	UPDATE DatabaseConfiguration SET Value = '8.6'
		WHERE Property = 'SchemaVersion'
	DELETE DatabaseConfiguration WHERE Property = 'MigrationStep'
END
GO
